# DEP03 - Infrastructure as Code

Quản lý infrastructure với code: Terraform, CloudFormation.

## Best Practices

| # | Best Practice | Mô tả |
|---|---------------|-------|
| BP01 | [Terraform Best Practices](DEP03-BP01-Terraform-Best-Practices.md) | IaC với Terraform |

## Tham khảo

- Terraform Documentation
- AWS CloudFormation
- Pulumi
